Send patches - preferably formatted by git format-patch - to patches at archlinux32 dot org.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--archinstall/lib/disk.py4
1 files changed, 2 insertions, 2 deletions
diff --git a/archinstall/lib/disk.py b/archinstall/lib/disk.py
index c721c90e..8eb4b54d 100644
--- a/archinstall/lib/disk.py
+++ b/archinstall/lib/disk.py
@@ -142,8 +142,8 @@ class Partition():
# in order to determain if we support it or not.
try:
self.format(self.filesystem, '/dev/null')
- except DiskError:
- pass # We supported it, but /dev/null is not formatable as expected
+ except SysCallError:
+ pass # We supported it, but /dev/null is not formatable as expected so the mkfs call exited with an error code
except UnknownFilesystemFormat as err:
raise err